@@ -1,14 +1,21 @@
 import json
 from collections import namedtuple
 
+import requests
 
-def call_api(movies_list, series_name):
+
+def call_api(movies_list, series_name, supress_print):
     MovieInfo = namedtuple("MovieInfo", "just_title year title director country stars descr length url")
     episode = 0
     for movie in movies_list:
         episode += 1
         movie_info = MovieInfo(*movie)
         addViaApi(movie_info, series_name)
+        if not supress_print:
+            print('Added "' + movie_info.title + '" via api')
+
+    if not supress_print:
+        print()
 
 
 def addViaApi(movie, collection=None, supplied_length=None):
@@ -25,8 +32,6 @@ def addViaApi(movie, collection=None, supplied_length=None):
         movie_length = supplied_length
     movie_dto["duration"] = movie_length
 
-    # print the json instead of calling api
-    print(json.dumps(movie_dto))
-    # response = requests.put(put_uri, json=movie_dto)
-    # if response.status_code != 200:
-    #     print("Error")
+    response = requests.put(put_uri, json=movie_dto)
+    if response.status_code != 200:
+        print("Error")
